==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1RollingUpdateDeploymentFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ExtensionsV1beta1RollingUpdateDeploymentFluentImpl<A extends ExtensionsV1beta1RollingUpdateDeploymentFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements ExtensionsV1beta1RollingUpdateDeploymentFluent<A>{

    private String maxSurge;
    private String maxUnavailable;

    public ExtensionsV1beta1RollingUpdateDeploymentFluentImpl(){
    }
    public ExtensionsV1beta1RollingUpdateDeploymentFluentImpl(ExtensionsV1beta1RollingUpdateDeployment instance){
            this.withMaxSurge(instance.getMaxSurge());

            this.withMaxUnavailable(instance.getMaxUnavailable());

    }

    public String getMaxSurge(){
            return this.maxSurge;
    }

    public A withMaxSurge(String maxSurge){
            this.maxSurge=maxSurge; return (A) this;
    }

    public Boolean hasMaxSurge(){
            return this.maxSurge != null;
    }

    public String getMaxUnavailable(){
            return this.maxUnavailable;
    }

    public A withMaxUnavailable(String maxUnavailable){
            this.maxUnavailable=maxUnavailable; return (A) this;
    }

    public Boolean hasMaxUnavailable(){
            return this.maxUnavailable != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExtensionsV1beta1RollingUpdateDeploymentFluentImpl that = (ExtensionsV1beta1RollingUpdateDeploymentFluentImpl) o;
            if (maxSurge != null ? !maxSurge.equals(that.maxSurge) :that.maxSurge != null) return false;
            if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1RollingUpdateDeploymentFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ExtensionsV1beta1RollingUpdateDeploymentFluentImpl<A extends ExtensionsV1beta1RollingUpdateDeploymentFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements ExtensionsV1beta1RollingUpdateDeploymentFluent<A>{

    private String maxSurge;
    private String maxUnavailable;

    public ExtensionsV1beta1RollingUpdateDeploymentFluentImpl(){
    }
    public ExtensionsV1beta1RollingUpdateDeploymentFluentImpl(ExtensionsV1beta1RollingUpdateDeployment instance){
            this.withMaxSurge(instance.getMaxSurge());

            this.withMaxUnavailable(instance.getMaxUnavailable());

    }

    public String getMaxSurge(){
            return this.maxSurge;
    }

    public A withMaxSurge(String maxSurge){
            this.maxSurge=maxSurge; return (A) this;
    }

    public Boolean hasMaxSurge(){
            return this.maxSurge != null;
    }

    public A withNewMaxSurge(String arg1){
            return (A)withMaxSurge(new String(arg1));
    }

    public A withNewMaxSurge(StringBuilder arg1){
            return (A)withMaxSurge(new String(arg1));
    }

    public A withNewMaxSurge(StringBuffer arg1){
            return (A)withMaxSurge(new String(arg1));
    }

    public String getMaxUnavailable(){
            return this.maxUnavailable;
    }

    public A withMaxUnavailable(String maxUnavailable){
            this.maxUnavailable=maxUnavailable; return (A) this;
    }

    public Boolean hasMaxUnavailable(){
            return this.maxUnavailable != null;
    }

    public A withNewMaxUnavailable(String arg1){
            return (A)withMaxUnavailable(new String(arg1));
    }

    public A withNewMaxUnavailable(StringBuilder arg1){
            return (A)withMaxUnavailable(new String(arg1));
    }

    public A withNewMaxUnavailable(StringBuffer arg1){
            return (A)withMaxUnavailable(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExtensionsV1beta1RollingUpdateDeploymentFluentImpl that = (ExtensionsV1beta1RollingUpdateDeploymentFluentImpl) o;
            if (maxSurge != null ? !maxSurge.equals(that.maxSurge) :that.maxSurge != null) return false;
            if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
            return true;
    }




}
